From::
  Channel flow past a cylindrical obstacle, using a LB method
  Copyright (C) 2006 Jonas Latt
  Address: Rue General Dufour 24,  1211 Geneva 4, Switzerland
  E-mail: Jonas.Latt@cui.unige.ch

Params example (height * width * iterations)::

  --size=1000*1000*10

